#!
#
#   poko.sh -- ¤Ý¤³¤Ý¤³
#

curtty=`tty | sed 's|/|-|g'`
pokochar=`sed -n '1p' < /tmp/poko-$curtty.txt`
case "x${pokochar}x" in
	xO*)   pokochar='¡û' ;;
	xo*)   pokochar='O ' ;;
	x¡£*)  pokochar='o ' ;;
	x.*)   pokochar='¡£' ;;
	*)     pokochar='. ' ;;
esac
echo -n "$pokochar "
echo "$pokochar" > /tmp/poko-$curtty.txt

exit 0

# EOF
