#! /bin/sh
#
#   startup.sh -- スタートアップスクリプト (floppy版)
#
#	0.0: Jun. 19, 2004 by Dai ISHIJIMA
#	0.1: Feb. 17, 2007 (乱数パターンと補数)
#	0.2: May  17, 2020 (v20)
#

PATH=/fd-mode:/wipeout
PATH=${PATH}:/usr.bin:/usr/bin:/usr/local/bin:/bin:/usr.sbin:/usr/sbin:/sbin
export PATH=${PATH}:.

export PATTERNFIL=/tmp/pattern.dat

# 起動時のシステムメッセージを保存
dmesg > /var/run/dmesg.boot

# ツール起動
cd /fd-mode
stuff -g > $PATTERNFIL
echo ''
echo '# ------------------------------------------------------------ #'
echo '# All console output will be logged in /tmp/fd-mode.log'
echo '# ------------------------------------------------------------ #'
echo ''
echo -n 'Press ENTER to proceed '
read x

/bin/sh /fd-mode/mainmenu.sh

# とりあえず対話シェルを動かしておく :-)
/bin/sh -i

exit 0

# EOF
