#!
#
#   poko.sh -- ¤Ý¤³¤Ý¤³ (1)
#

curtty=`tty | sed 's|/|-|g'`
pokochar=`head -1 /tmp/poko-$curtty.txt`
case "x${pokochar}x" in
	xo*)   pokochar='O' ;;
	x.*)   pokochar='o' ;;
	*)     pokochar='.' ;;
esac
echo -n "$pokochar "
echo "$pokochar" > /tmp/poko-$curtty.txt

exit 0

# EOF
