#! /bin/sh
#
#   scsaver.sh -- スクリーンセーバー
#
#	0.0: Nov.  8, 2015 by Dai ISHIJIMA (for wpout15)
#

STATEFIL="${STATEFIL:-/tmp/status.txt}"
HISTFIL="${HISTFIL:-/tmp/history.txt}"

xpos=0
ypos=0

xmov=13
ymov=19

xmax=40
ymax=23

while true ; do
	npid=`sh -c 'echo "$$"'`
	#nsec=`date '+%S'` ### 08 とかはエラー
	xpos=$(( (( $xpos + $xmov + $npid ) % xmax) + 1 ))
	ypos=$(( (( $ypos + $ymov + $npid ) % ymax) + 1 ))
	# clear screen
	echo -e '\e[H\e[J\c'
	# move cursor
	echo -e '\e['"$ypos"';'"$xpos"'H\c'
	if [ -s $STATEFIL ]; then
		sed -n '$p' < $STATEFIL
	else
		sed -n '$p' < $HISTFIL
	fi
	ypos=$(( $ypos + 1 ))
	echo -e '\e['"$ypos"';'"$xpos"'H\c'
	echo -n 'Alt+F1 to main screen...'
	sleep 3
done